@@ -11,26 +11,35 @@ sub description { "This tool will run a demo server with a mock DB" }
 
 sub opt_spec {
     return (
-        [ "server|s", "Run a PONAPI demo server" ],
-        [ "query|q",  "Execute a query from the demo server" ],
-        [ "port=i",   "Specify a port for the server (default=5000)" ],
+        [ "s|server",  "Run a local PONAPI demo server" ],
+        [ "q|query:s", "Send a random/provided query to local server" ],
+        [ "p|port=i",  "Specify a port for the server (default=5000)" ],
     );
 }
 
 sub validate_args {
     my ( $self, $opt, $args ) = @_;
 
-    $self->usage_error("one of server (-s) or query (-q) is required.\n")
-        unless $opt->{server} xor $opt->{query};
+    $self->usage_error("(only) one of server (-s) or query (-q [STR]) is required.\n")
+        unless exists $opt->{s} xor exists $opt->{q};
 
-    $self->{port} = $opt->{port} || 5000;
+    $self->{port} = $opt->{port} || $opt->{p} || 5000;
+
+    $self->{query_string} = "";
+
+    if ( exists $opt->{q} and $opt->{q} ) {
+        $opt->{q} =~ s|^/||;
+        $self->{query_string} =
+            ( $opt->{q} !~ /^http/ ? 'http://localhost:' . $self->{port} . '/' : '' )
+            . $opt->{q}
+    }
 }
 
 sub execute {
     my ( $self, $opt, $args ) = @_;
 
-    $self->run_server() if $opt->{server};
-    $self->run_query()  if $opt->{query};
+    $self->run_server() if exists $opt->{s};
+    $self->run_query()  if exists $opt->{q};
 }
 
 sub run_server {
@@ -80,7 +89,7 @@ sub run_query {
     require JSON::XS;
     require HTTP::Tiny;
 
-    my $url = 'http://localhost:' . $self->{port} . '/articles/2?include=comments,authors';
+    my $url = $self->{query_string} || $self->random_url();
 
     my $res = HTTP::Tiny->new->get( $url, {
         headers => {
@@ -88,6 +97,9 @@ sub run_query {
         },
     });
 
+    die "Failed to connect to a local server (try 'ponapi demo -s' to start one)\n"
+        unless $res and ref($res) eq 'HASH' and $res->{status} < 500;
+
     print "\nGET $url\n\n";
     print $res->{protocol} . " " . $res->{status} . " " . $res->{reason} . "\n";
 
@@ -97,6 +109,62 @@ sub run_query {
     print $json->pretty(1)->encode( $json->decode($res->{content}) );
 }
 
+sub random_url {
+    my $self = shift;
+
+    my %rels = (
+        articles => {
+            id      => [ 1, 2, 3 ],
+            include => [qw< comments authors >],
+            fields  => [qw< body title created updated status >],
+        },
+        comments => {
+            id      => [ 5, 12 ],
+            include => [qw< articles >],
+        },
+        people   => {
+            id      => [ 42, 88, 91 ],
+            include => [qw< articles >],
+            fields  => [qw< name age gender >],
+        },
+    );
+
+    my $type = ( keys %rels )[ int(rand( scalar keys %rels )) ];
+
+    my $id = "";
+    if ( int(rand(2)) % 2 == 0 ) {
+        my $_id  = $rels{$type}{id}->[ int(rand(scalar @{ $rels{$type}{id} } )) ];
+        $id = "/$_id";
+    }
+
+    my $include = "";
+    my @include;
+    if ( int(rand(2)) % 2 == 0 ) {
+        my @_inc = @{ $rels{$type}{include} };
+        @include = scalar @_inc > 1
+            ? map { int(rand(2)) % 2 ? $_ : () } @_inc
+            : @_inc;
+
+        $include = "include=" . ( join ',' => @include )
+            if @include;
+    }
+
+    my $fields = "";
+    if ( int(rand(2)) % 2 == 0 ) {
+        my @fields  = map { int(rand(2)) % 2 ? $_ : () } @{ $rels{$type}{fields} };
+        $fields = "fields[$type]=" . ( join ',' => @fields, @include )
+            if @fields;
+    }
+
+    my $query = ( $include || $fields ? "?" : "" );
+    my $sep   = ( $include && $fields ? "&" : "" );
+
+    my $url = 'http://localhost:' . $self->{port}
+            . "/$type" . $id . $query . $include . $sep . $fields;
+
+    return $url;
+}
+
 1;
 
 __END__
@@ -111,7 +179,7 @@ PONAPI::CLI::Command::demo - ponapi demo running command line utility
 
 =head1 VERSION
 
-version 0.002010
+version 0.002011
 
 =head1 AUTHORS
 
